# Changelog
All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]
## [0.1.0]
### Added
- Basic QUA Client connecting to the info service collecting capabilities
and implementation details
- Server tests folder to test if a server is compatible with the API

[Unreleased]: https://github.com/qua-platform/qua-sdk-py/compare/v0.1.0...HEAD
[0.1.0]: https://github.com/qua-platform/qua-sdk-py/releases/tag/v0.1.0